# Pyutttils [![Build Status](https://travis-ci.com/larueli/pyutttils.svg?branch=master)](https://travis-ci.com/larueli/pyutttils)

Ce package permet de fournir des fonctions utilitaires pour l'Université de Technologie de Troyes.

# Quickstart

`pip install pyutttils`

Dans votre code python :

```
from pyutttils import utt_auth
sessionSMTP = utt_auth.smtp() 
```

# Documentation

La documentation du package se trouve à [https://larueli.github.io/pyutttils/](https://larueli.github.io/pyutttils/)